@@ -25,5 +25,5 @@ def create_proto_file(package: str) -> None:
 
     pwd = Path(settings.proto_folder)
     pwd.mkdir(exist_ok=True)
-    with open(pwd.jonipath(f'{package}.proto'), 'w') as f:
+    with open(pwd.joinpath(f'{package}.proto'), 'w') as f:
         f.write(content)
