@@ -7,7 +7,7 @@ from grpc._server import _Server
 from protmo.pm import name_to_grpc_message_or_method
 from protmo.utils import *
 from protmo.server.generic_servicer import GenericServicer
-
+import os
 
 
 
@@ -16,9 +16,15 @@ def run_server(): # -> NoReturn:
     You first have to load all modules (as defined in your settings.py) and then
     serve them. This methods helps you with it.
     '''
+    trust_local_certificates()
     load_modules()
     serve()
 
+def trust_local_certificates():
+    # Tested only on Ubuntu 22.04
+    # You can add it there via mkcert
+    os.environ['REQUESTS_CA_BUNDLE']='/etc/ssl/certs/ca-certificates.crt'
+
 
 def load_modules() -> None:
     '''
